@@ -19,11 +19,11 @@
 #This file is used to display the main menu upon startup.
 
 from os import path, listdir
+import ConfigParser
 
 import pygame
 import g
 
-
 import buttons
 import scrollbar
 import listbox
@@ -63,19 +63,19 @@ def display_main_menu():
             for button in menu_buttons:
                 if button.was_activated(event):
                     if button.button_id == "NEW GAME":
-                        g.play_click()
+                        g.play_sound("click")
                         return 0
                     elif button.button_id == "LOAD GAME":
-                        g.play_click()
+                        g.play_sound("click")
                         return 1
                     elif button.button_id == "OPTIONS":
-                        g.play_click()
+                        g.play_sound("click")
                         return 4
                     elif button.button_id == "ABOUT":
-                        g.play_click()
+                        g.play_sound("click")
                         return 3
                     if button.button_id == "QUIT":
-                        g.play_click()
+                        g.play_sound("click")
                         return 2
 
 def difficulty_select():
@@ -115,27 +115,27 @@ def difficulty_select():
             for button in diff_buttons:
                 if button.was_activated(event):
                     if button.button_id == "VERY EASY":
-                        g.play_click()
+                        g.play_sound("click")
                         g.new_game(1)
                         return 1
                     elif button.button_id == "EASY":
-                        g.play_click()
+                        g.play_sound("click")
                         g.new_game(3)
                         return 1
                     elif button.button_id == "NORMAL":
-                        g.play_click()
+                        g.play_sound("click")
                         g.new_game(5)
                         return 1
                     elif button.button_id == "HARD":
-                        g.play_click()
+                        g.play_sound("click")
                         g.new_game(7)
                         return 1
                     elif button.button_id == "IMPOSSIBLE":
-                        g.play_click()
+                        g.play_sound("click")
                         g.new_game(9)
                         return 1
                     elif button.button_id == "BACK":
-                        g.play_click()
+                        g.play_sound("click")
                         return 0
 
 def display_load_menu():
@@ -244,10 +244,10 @@ def display_load_menu():
             for button in menu_buttons:
                 if button.was_activated(event):
                     if button.button_id == "LOAD":
-                        g.play_click()
+                        g.play_sound("click")
                         return saves_array[saves_pos]
                     elif button.button_id == "BACK":
-                        g.play_click()
+                        g.play_sound("click")
                         return -1
             tmp = saves_scroll.adjust_pos(event, saves_pos, saves_array)
             if tmp != saves_pos:
@@ -388,11 +388,11 @@ def display_options():
             for button in menu_buttons:
                 if button.was_activated(event):
                     if button.button_id == "BACK":
-                        g.play_click()
+                        g.play_sound("click")
                         set_language_properly(prev_lang)
                         return 0
                     if button.button_id == "SAVE TO DISK":
-                        g.play_click()
+                        g.play_sound("click")
                         if lang_pos >= len(lang_array):
                             save_options()
                         else:
@@ -402,29 +402,29 @@ def display_options():
                     elif button.button_id == "fullscreen":
                         if g.fullscreen == 1: g.fullscreen = 0
                         else: g.fullscreen = 1
-                        g.play_click()
+                        g.play_sound("click")
                         set_res()
                     elif button.button_id == "sound":
                         if g.nosound == 1: g.nosound = 0
                         else: g.nosound = 1
-                        g.play_click()
+                        g.play_sound("click")
                     elif button.button_id == "grab":
-                        g.play_click()
+                        g.play_sound("click")
                         pygame.event.set_grab(not pygame.event.get_grab())
                     elif button.button_id == "640":
-                        g.play_click()
+                        g.play_sound("click")
                         g.screen_size = (640, 480)
                         set_res()
                     elif button.button_id == "800":
-                        g.play_click()
+                        g.play_sound("click")
                         g.screen_size = (800, 600)
                         set_res()
                     elif button.button_id == "1024":
-                        g.play_click()
+                        g.play_sound("click")
                         g.screen_size = (1024, 768)
                         set_res()
                     elif button.button_id == "1280":
-                        g.play_click()
+                        g.play_sound("click")
                         g.screen_size = (1280, 1024)
                         set_res()
                     click_button(menu_buttons, button, False)
@@ -468,20 +468,33 @@ def set_language_properly(prev_lang):
     g.load_string_defs(g.language)
 
 def save_options(lang=""):
+
+    # Open up the preferences file for writing.
     save_dir = g.get_save_folder(True)
-    save_loc = path.join(save_dir, "prefs.txt")
-    savefile=open(save_loc, 'w')
-    savefile.write("fullscreen="+str(g.fullscreen)+"\n")
-    savefile.write("nosound="+str(g.nosound)+"\n")
-    savefile.write("grab="+str(pygame.event.get_grab())+"\n")
-    savefile.write("xres="+str(g.screen_size[0])+"\n")
-    savefile.write("yres="+str(g.screen_size[1])+"\n")
-    if lang != "":
-        savefile.write("lang="+lang+"\n")
+    save_loc = path.join(save_dir, "prefs.dat")
+    savefile = open(save_loc, 'w')
+
+    # Build a ConfigParser for writing the various preferences out.
+    prefs = ConfigParser.SafeConfigParser()
+    prefs.add_section("Preferences")
+    prefs.set("Preferences", "fullscreen", str(g.fullscreen))
+    prefs.set("Preferences", "nosound", str(g.nosound))
+    prefs.set("Preferences", "grab", str(pygame.event.get_grab()))
+    prefs.set("Preferences", "xres", str(g.screen_size[0]))
+    prefs.set("Preferences", "yres", str(g.screen_size[1]))
+
+    # If the user has a custom language set, save it.
+    if lang:
+        prefs.set("Preferences", "lang", lang)
+
+    # Actually write the preferences out.
+    prefs.write(savefile)
     savefile.close()
+
+    # Show the user that we've saved their options.
     g.create_dialog("\\n Options Saved", g.font[0][22],
-            (g.screen_size[0]/2-70, 250), (140, 90),
-            g.colors["blue"], g.colors["white"], g.colors["white"])
+     (g.screen_size[0]/2-70, 250), (140, 90),
+     g.colors["blue"], g.colors["white"], g.colors["white"])
 
 def refresh_options(menu_buttons):
     #Border
@@ -517,4 +530,3 @@ def refresh_options(menu_buttons):
     #Language
     g.print_string(g.screen, "Language:",
             g.font[0][22], -1, (xstart+20, ystart+200), g.colors["white"])
-
